@@ -1,8 +1,10 @@
 mod base;
 mod local_redirector;
+mod tun;
 mod udp;
 mod wireguard;
 
 pub use local_redirector::{start_local_redirector, LocalRedirector};
+pub use tun::{create_tun_interface, TunInterface};
 pub use udp::{start_udp_server, UdpServer};
 pub use wireguard::{start_wireguard_server, WireGuardServer};
