@@ -147,16 +147,13 @@ impl PacketSourceTask for MacOsTask {
                             );
                             self.connections.spawn(task.run());
                         },
-                        Err(e) => log::error!("Error accepting connection from macos-redirector: {}", e)
+                        Err(e) => log::error!("Error accepting connection from macos-redirector: {e}")
                     }
                 },
                 // pipe through changes to the intercept list
                 Some(conf) = self.conf_rx.recv() => {
-                    let msg = ipc::InterceptConf::from(conf);
-                    let len = msg.encoded_len();
-                    let mut buf = BytesMut::with_capacity(len);
-                    msg.encode(&mut buf)?;
-                    control_channel.send(buf.freeze()).await.context("Failed to write to control channel")?;
+                    let msg = ipc::InterceptConf::from(conf).encode_to_vec();
+                    control_channel.send(Bytes::from(msg)).await.context("Failed to write to control channel")?;
                 },
             }
         }
@@ -191,12 +188,12 @@ impl ConnectionTask {
                 .read_u32()
                 .await
                 .context("Failed to read handshake.")? as usize;
-            let mut buf = BytesMut::zeroed(len);
+            let mut buf = vec![0; len];
             self.stream
                 .read_exact(&mut buf)
                 .await
                 .context("Failed to read handshake contents.")?;
-            NewFlow::decode(&buf[..]).context("Invalid handshake IPC")?
+            NewFlow::decode(buf.as_slice()).context("Invalid handshake IPC")?
         };
 
         match new_flow {
@@ -237,7 +234,7 @@ impl ConnectionTask {
                 bail!("no local address")
             };
             SocketAddr::try_from(addr)
-                .with_context(|| format!("invalid local_address: {:?}", addr))?
+                .with_context(|| format!("invalid local_address: {addr:?}"))?
         };
         let mut remote_address = SocketAddr::new(IpAddr::V4(Ipv4Addr::UNSPECIFIED), 0);
         let (command_tx, mut command_rx) = unbounded_channel();
@@ -255,7 +252,7 @@ impl ConnectionTask {
                     ).context("invalid IPC message")?;
                     let dst_addr = {
                         let Some(dst_addr) = &packet.remote_address else { bail!("no remote addr") };
-                        SocketAddr::try_from(dst_addr).with_context(|| format!("invalid remote_address: {:?}", dst_addr))?
+                        SocketAddr::try_from(dst_addr).with_context(|| format!("invalid remote_address: {dst_addr:?}"))?
                     };
 
                     // We can only send ConnectionEstablished once we know the destination address.
@@ -338,7 +335,9 @@ impl ConnectionTask {
             tokio::select! {
                 _ = self.shutdown.recv() => break,
                 Ok(()) = self.stream.writable(), if !write_buf.is_empty() => {
-                    self.stream.write_buf(&mut write_buf).await.context("failed to write to socket from buf")?;
+                    let Ok(_) = self.stream.write_buf(&mut write_buf).await else {
+                        break;  // Client has disconnected.
+                    };
                     if write_buf.is_empty() {
                         if let Some(tx) = drain_tx.take() {
                             tx.send(()).ok();
